@@ -172,7 +172,7 @@ Arnolfini.getPrevEvent = function ()
 }
 
 $(document).ready(function() {
-	Arnolfini.events();
+	//Arnolfini.events();
 	Arnolfini.archiveShowButtons();
 });
 
