@@ -234,6 +234,7 @@ class FolderListing(CommonBrowserView):
     Override of folder_listing view
     """
     def results(self, b_start = 0, pagesize=10, only_documented=False):
+        results = []
         
         if self.context.portal_type  == 'Collection':
             brains = self.context.queryCatalog(batch=False)
@@ -245,7 +246,7 @@ class FolderListing(CommonBrowserView):
             else:
                 final_res = list(brains)
             results = Batch(final_res, pagesize, start=b_start)
-        elif self.context.portal_type  == 'folder':
+        elif self.context.portal_type  == 'Folder':
             brains = self.context.getFolderContents()
             if only_documented:
                 final_res = []
